State class

State represents all information about a sequence necessary to generate the current output. Note that a state is immutable.

Constructors

State(Token _token, HighLevelEncoderMode _mode, int _binaryShiftByteCount, int _bitCount, [int? binaryShiftCost])

Properties

binaryShiftByteCount → int
no setter
bitCount → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
mode → HighLevelEncoderMode
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → Token
no setter

Methods

addBinaryShiftChar(int index) → State
appendFLGn(int eci) → State
endBinaryShift(int index) → State
isBetterThanOrEqualTo(State other) → bool
latchAndAppend(HighLevelEncoderMode mode, int value) → State
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shiftAndAppend(HighLevelEncoderMode mode, int value) → State
toBitArray(List<int> text) → BitArray
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

initialState → State
final