AddressBookParsedResult class

Represents a parsed result that encodes contact information, like that in an address book entry.

@author Sean Owen

Inheritance

Constructors

AddressBookParsedResult({List<String>? names, List<String>? nicknames, String? pronunciation, List<String>? phoneNumbers, List<String?>? phoneTypes, List<String>? emails, List<String?>? emailTypes, String? instantMessenger, String? note, List<String>? addresses, List<String?>? addressTypes, String? org, String? birthday, String? title, List<String>? urls, List<String>? geo})
AddressBookParsedResult.full(List<String>? _names, List<String>? _nicknames, String? pronunciation, List<String>? _phoneNumbers, List<String?>? _phoneTypes, List<String>? _emails, List<String?>? _emailTypes, String? instantMessenger, String? note, List<String>? _addresses, List<String?>? _addressTypes, String? org, String? birthday, String? title, List<String>? _urls, List<String>? geo)
AddressBookParsedResult.quick(List<String>? names, List<String>? phoneNumbers, List<String?>? phoneTypes, List<String>? emails, List<String?>? emailTypes, List<String>? addresses, List<String>? addressTypes)

Properties

addresses → List<String>?
no setter
addressTypes → List<String?>?
@return optional descriptions of the type of each e-mail. It could be like "WORK", but, there is no guaranteed or standard format.
no setter
birthday ↔ String?
birthday formatted as yyyyMMdd (e.g. 19780917)
getter/setter pair
displayResult → String
no setteroverride
emails → List<String>?
no setter
emailTypes → List<String?>?
@return optional descriptions of the type of each e-mail. It could be like "WORK", but, there is no guaranteed or standard format.
no setter
geo ↔ List<String>?
A location as a latitude/longitude pair
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instantMessenger ↔ String?
getter/setter pair
names → List<String>?
no setter
nicknames → List<String>?
no setter
note ↔ String?
getter/setter pair
org ↔ String?
getter/setter pair
phoneNumbers → List<String>?
no setter
phoneTypes → List<String?>?
@return optional descriptions of the type of each phone number. It could be like "HOME", but, there is no guaranteed or standard format.
no setter
pronunciation ↔ String?
The pronunciation of the getNames() field, often in hiragana or katakana.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair
type → ParsedResultType
no setterinherited
urls → List<String>?
no setter

Methods

addAddress(String address, [String? type]) → void
addEmail(String email, [String? type]) → void
addName(String name) → void
addNickname(String name) → void
addPhoneNumber(String phone, [String? type]) → void
maybeAppend(String? value, StringBuffer result) → void
inherited
maybeAppendList(List<String>? values, StringBuffer result) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited