ExpandedProductParsedResult class

Represents a parsed result that encodes extended product information as encoded by the RSS format, like weight, price, dates, etc.

@author Antonio Manuel Benjumea Conde, Servinform, S.A. @author Agustín Delgado, Servinform, S.A.

Inheritance

Constructors

ExpandedProductParsedResult(String? rawText, String? productID, String? sscc, String? lotNumber, String? productionDate, String? packagingDate, String? bestBeforeDate, String? expirationDate, String? weight, String? weightType, String? weightIncrement, String? price, String? priceIncrement, String? priceCurrency, Map<String, String> uncommonAIs)

Properties

bestBeforeDate ↔ String?
getter/setter pair
displayResult → String
no setteroverride
expirationDate ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
lotNumber ↔ String?
getter/setter pair
packagingDate ↔ String?
getter/setter pair
price ↔ String?
getter/setter pair
priceCurrency ↔ String?
getter/setter pair
priceIncrement ↔ String?
getter/setter pair
productID ↔ String?
getter/setter pair
productionDate ↔ String?
getter/setter pair
rawText ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sscc ↔ String?
getter/setter pair
type → ParsedResultType
no setterinherited
uncommonAIs ↔ Map<String, String>
getter/setter pair
weight ↔ String?
getter/setter pair
weightIncrement ↔ String?
getter/setter pair
weightType ↔ String?
getter/setter pair

Methods

maybeAppend(String? value, StringBuffer result) → void
inherited
maybeAppendList(List<String>? values, StringBuffer result) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

kilogram → const String
pound → const String