GeoParsedResult class

Represents a parsed result that encodes a geographic coordinate, with latitude, longitude and altitude.

@author Sean Owen

Inheritance

Constructors

GeoParsedResult(double latitude, double longitude, [double altitude = 0, String? query])

Properties

altitude ↔ double
altitude in meters. If not specified, in the geo URI, returns 0.0
getter/setter pair
displayResult → String
no setteroverride
geoURI → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
latitude ↔ double
latitude in degrees
getter/setter pair
longitude ↔ double
longitude in degrees
getter/setter pair
query ↔ String?
query string associated with geo URI or null if none exists
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ParsedResultType
no setterinherited

Methods

maybeAppend(String? value, StringBuffer result) → void
inherited
maybeAppendList(List<String>? values, StringBuffer result) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited