SMSParsedResult class

Represents a parsed result that encodes an SMS message, including recipients, subject and body text.

@author Sean Owen

Inheritance

Constructors

SMSParsedResult(List<String> _numbers, List<String>? _vias, String? subject, String? body)
SMSParsedResult.single(String number, String? via, String? subject, String? body)

Properties

body ↔ String?
getter/setter pair
displayResult → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
numbers → List<String>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smsURI → String
no setter
subject ↔ String?
getter/setter pair
type → ParsedResultType
no setterinherited
vias → List<String>?
no setter

Methods

addNumber(String num, [String? via]) → void
maybeAppend(String? value, StringBuffer result) → void
inherited
maybeAppendList(List<String>? values, StringBuffer result) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited