TextParsedResult class

A simple result type encapsulating a string that has no further interpretation.

@author Sean Owen

Inheritance

Constructors

TextParsedResult(String text, [String? language])

Properties

displayResult → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
language ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair
type → ParsedResultType
no setterinherited

Methods

maybeAppend(String? value, StringBuffer result) → void
inherited
maybeAppendList(List<String>? values, StringBuffer result) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited