VINResultParser class

Detects a result that is likely a vehicle identification number.

@author Sean Owen

Inheritance

Constructors

VINResultParser()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isStringOfDigits(String? value, int length) → bool
inherited
matchPrefixedField(String prefix, String rawText, String endChar, bool trim) → List<String>?
inherited
matchSinglePrefixedField(String prefix, String rawText, String endChar, bool trim) → String?
inherited
maybeWrap(String? value) → List<String>?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(Result result) → VINParsedResult?
Attempts to parse the raw Result's contents as a particular type of information (email, URL, etc.) and return a ParsedResult encapsulating the result of parsing.
override
parseNameValuePairs(String uri) → Map<String, String>?
inherited
toString() → String
A string representation of this object.
inherited
unescapeBackslash(String escaped) → String
inherited
urlDecode(String encoded) → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited