DetectorResult class

Encapsulates the result of detecting a barcode in an image.

This includes the raw matrix of black/white pixels corresponding to the barcode, and possibly points of interest in the image, like the location of finder patterns or corners of the barcode in the image.

@author Sean Owen

Implementers

Constructors

DetectorResult(BitMatrix bits, List<ResultPoint> points)

Properties

bits → BitMatrix
final
hashCode → int
The hash code for this object.
no setterinherited
points → List<ResultPoint>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited