InputEdge class

Constructors

InputEdge(int c, ECIEncoderSet encoderSet, int encoderIndex, InputEdge? previous, int fnc1)

Properties

c → int
final
cachedTotalSize ↔ int
getter/setter pair
encoderIndex → int
final
hashCode → int
The hash code for this object.
no setterinherited
isFNC1 → bool
no setter
previous → InputEdge?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited