DataMatrixSymbolInfo144 class

Inheritance

Constructors

DataMatrixSymbolInfo144()
const

Properties

codewordCount → int
no setterinherited
dataCapacity → int
no setterinherited
errorCodewords → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
interleavedBlockCount → int
no setteroverride
matrixHeight → int
finalinherited
matrixWidth → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbolDataHeight → int
no setterinherited
symbolDataWidth → int
no setterinherited
symbolHeight → int
no setterinherited
symbolWidth → int
no setterinherited

Methods

getDataLengthForInterleavedBlock(int index) → int
override
getErrorLengthForInterleavedBlock(int index) → int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited