DefaultPlacement class

Symbol Character Placement Program. Adapted from Annex M.1 in ISO/IEC 16022:2000(E).

Constructors

DefaultPlacement(String _codewords, int _numCols, int _numRows)
Main constructor

Properties

bits → Uint8List
no setter
hashCode → int
The hash code for this object.
no setterinherited
numCols → int
no setter
numRows → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBit(int col, int row) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
place() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited