Edge class

Constructors

Edge(Input input, Mode mode, int fromPosition, int characterLength, Edge? previous)

Properties

cachedTotalSize ↔ int
getter/setter pair
characterLength → int
final
endMode → Mode
Returns Mode.ASCII in case that:
no setter
fromPosition → int
final
hashCode → int
The hash code for this object.
no setterinherited
input → Input
final
mode → Mode
final
previous → Edge?
final
previousMode → Mode
no setter
previousStartMode → Mode
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getB256Size() → int
does not count beyond 250
getC40Words(bool c40, int fnc1) → Uint8List
getCodewordsRemaining(int minimum) → int
Returns the remaining capacity in codewords of the smallest symbol that has enough capacity to fit the given minimal number of codewords.
getDataBytes() → Uint8List
getEDFBytes() → Uint8List
getLastASCII() → int
Peeks ahead and returns 1 if the postfix consists of exactly two digits, 2 if the postfix consists of exactly two consecutive digits and a non extended character or of 4 digits. Returns 0 in any other case
getLatchBytes() → Uint8List
getMinSymbolSize(int minimum) → int
Returns the capacity in codewords of the smallest symbol that has enough capacity to fit the given minimal number of codewords.
getMode() → Mode
getX12Words() → Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getBytes(int c, [int? c2]) → Uint8List
getC40Value(bool c40, int setIndex, int c, int fnc1) → int
getShiftValue(int c, bool c40, int fnc1) → int
getX12Value(int c) → int
setC40Word(Uint8List bytes, int offset, int c1, int c2, int c3) → void