HighLevelEncoder class

DataMatrix ECC 200 data encoder following the algorithm described in ISO/IEC 16022:200(E) in annex S.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

determineConsecutiveDigitCount(String msg, int startPos) → int
Determines the number of consecutive characters that are encodable using numeric compaction.
encodeHighLevel(String msg, [SymbolShapeHint shape = SymbolShapeHint.forceNone, Dimension? minSize, Dimension? maxSize, bool forceC40 = false]) → String
Performs message encoding of a DataMatrix message using the algorithm described in annex P of ISO/IEC 16022:2000(E).
illegalCharacter(int c) → void
isDigit(int chr) → bool
isExtendedASCII(dynamic chr) → bool
isNativeC40(dynamic chr) → bool
isNativeEDIFACT(int chr) → bool
isNativeText(dynamic chr) → bool
isNativeX12(int chr) → bool
lookAheadTest(String msg, int startPos, int currentMode) → int
lookAheadTestIntern(String msg, int startPos, int currentMode) → int
min(List<int> lists) → int

Constants

asciiEncodation → const int
base256Encodation → const int
c40Encodation → const int
c40Unlatch → const int
ECI character (Extended Channel Interpretation) Unlatch from C40 encodation
edifactEncodation → const int
latchToAnsix12 → const int
mode latch to ANSI X.12 encodation mode
latchToBase256 → const int
mode latch to Base 256 encodation mode
latchToC40 → const int
mode latch to C40 encodation mode
latchToEdifact → const int
mode latch to EDIFACT encodation mode
latchToText → const int
mode latch to Text encodation mode
macro05Header → const String
05 Macro header
macro06Header → const String
06 Macro header
macroTrailer → const String
Macro trailer
textEncodation → const int
upperShift → const int
FNC1 Codeword Structured Append Codeword Reader Programming Upper Shift chr
x12Encodation → const int
x12Unlatch → const int
Unlatch from X12 encodation