SymbolInfo class

Symbol info table for DataMatrix.

Implementers

Constructors

SymbolInfo(bool _rectangular, int _dataCapacity, int _errorCodewords, int matrixWidth, int matrixHeight, int _dataRegions, [int? rsBlockData, int? rsBlockError])
const

Properties

codewordCount → int
no setter
dataCapacity → int
no setter
errorCodewords → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
interleavedBlockCount → int
no setter
matrixHeight → int
final
matrixWidth → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbolDataHeight → int
no setter
symbolDataWidth → int
no setter
symbolHeight → int
no setter
symbolWidth → int
no setter

Methods

getDataLengthForInterleavedBlock(int index) → int
getErrorLengthForInterleavedBlock(int index) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

lookup(int dataCodewords, [Object? shapeOrIsRect, Object? minSizeOrFail, Dimension? maxSize, bool fail = true]) → SymbolInfo?
overrideSymbolSet(List<SymbolInfo> override) → void
Overrides the symbol info set used by this class. Used for testing purposes.

Constants

prodSymbols → const List<SymbolInfo>