Version class

The Version object encapsulates attributes about a particular size Data Matrix Code.

@author bbrown@google.com (Brian Brown)

Properties

dataRegionSizeColumns → int
no setter
dataRegionSizeRows → int
no setter
ecBlocks → ECBlocks
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbolSizeColumns → int
no setter
symbolSizeRows → int
no setter
totalCodewords → int
no setter
versionNumber → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getVersionForDimensions(int numRows, int numColumns) → Version
Deduces version information from Data Matrix dimensions.