MultipleBarcodeReader class abstract

Implementation of this interface attempt to read several barcodes from one image.

See Reader

@see com.google.zxing.Reader @author Sean Owen

Implementers

Constructors

MultipleBarcodeReader()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeMultiple(BinaryBitmap image, [DecodeHint? hints]) → List<Result>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited