DataCharacter class

Encapsulates a since character value in an RSS barcode, including its checksum information.

Implementers

Constructors

DataCharacter(int _value, int _checksumPortion)

Properties

checksumPortion → int
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override