DecodedInformation class

@author Pablo Orduña, University of Deusto (pablo.orduna@deusto.es) @author Eduardo Castillejo, University of Deusto (eduardo.castillejo@deusto.es)

Inheritance

Constructors

DecodedInformation(int newPosition, String _newString, [int _remainingValue = 0])

Properties

hashCode → int
The hash code for this object.
no setterinherited
isRemaining → bool
no setter
newPosition → int
no setterinherited
newString → String
no setter
remainingValue → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited