DecodedNumeric class

@author Pablo Orduña, University of Deusto (pablo.orduna@deusto.es) @author Eduardo Castillejo, University of Deusto (eduardo.castillejo@deusto.es)

Inheritance

Constructors

DecodedNumeric(int newPosition, int _firstDigit, int _secondDigit)

Properties

firstDigit → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
isFirstDigitFNC1 → bool
no setter
isSecondDigitFNC1 → bool
no setter
newPosition → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondDigit → int
no setter
value → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

fnc1 → int
final