ExpandedPair class

@author Pablo Orduña, University of Deusto (pablo.orduna@deusto.es)

Constructors

ExpandedPair(DataCharacter? _leftChar, DataCharacter? _rightChar, FinderPattern? _finderPattern)

Properties

finderPattern → FinderPattern?
no setter
hashCode → int
The hash code for this object.
no setteroverride
leftChar → DataCharacter?
no setter
mustBeLast → bool
no setter
rightChar → DataCharacter?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override