FinderPattern class

Encapsulates an RSS barcode finder pattern, including its start/end position and row.

Constructors

FinderPattern(int _value, List<int> _startEnd, int start, int end, int rowNumber)

Properties

hashCode → int
The hash code for this object.
no setteroverride
resultPoints → List<ResultPoint>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startEnd → List<int>
no setter
value → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override