GeneralAppIdDecoder class

@author Pablo Orduña, University of Deusto (pablo.orduna@deusto.es) @author Eduardo Castillejo, University of Deusto (eduardo.castillejo@deusto.es)

Constructors

GeneralAppIdDecoder(BitArray _information)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeAllCodes(StringBuffer buff, int initialPosition) → String
decodeGeneralPurposeField(int pos, String? remaining) → DecodedInformation
extractNumericValueFromBitArray(int pos, int bits) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

extractNumericFromBitArray(BitArray information, int pos, int bits) → int