BarcodeMatrix class

Holds all of the information for a barcode in a format where it can be easily accessible

@author Jacob Haynes

Constructors

BarcodeMatrix(int _height, int width)
@param height the height of the matrix (Rows) @param width the width of the matrix (Cols)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCurrentRow() → BarcodeRow
getMatrix() → List<Uint8List>
getScaledMatrix(int xScale, int yScale) → List<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(int x, int y, int value) → void
startRow() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited