BarcodeMetadata class

@author Guenther Grau

Constructors

BarcodeMetadata(int _columnCount, int _rowCountUpperPart, int _rowCountLowerPart, int _errorCorrectionLevel)

Properties

columnCount → int
no setter
errorCorrectionLevel → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
rowCount → int
no setter
rowCountLowerPart → int
no setter
rowCountUpperPart → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited