BarcodeValue class

@author Guenther Grau

Constructors

BarcodeValue()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConfidence(int value) → int
getValue() → List<int>
Determines the maximum occurrence of a set value and returns all values which were set with this occurrence. @return an array of int, containing the values with the highest occurrence, or null, if no value was set
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(int value) → void
Add an occurrence of a value
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited