BoundingBox class

@author Guenther Grau

Constructors

BoundingBox(BitMatrix _image, ResultPoint? topLeft, ResultPoint? bottomLeft, ResultPoint? topRight, ResultPoint? bottomRight)
BoundingBox.copy(BoundingBox boundingBox)

Properties

bottomLeft → ResultPoint
no setter
bottomRight → ResultPoint
no setter
hashCode → int
The hash code for this object.
no setterinherited
maxX → int
no setter
maxY → int
no setter
minX → int
no setter
minY → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeft → ResultPoint
no setter
topRight → ResultPoint
no setter

Methods

addMissingRows(int missingStartRows, int missingEndRows, bool isLeft) → BoundingBox
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

merge(BoundingBox? leftBox, BoundingBox? rightBox) → BoundingBox?