Codeword class

@author Guenther Grau

Constructors

Codeword(int _startX, int _endX, int _bucket, int _value)

Properties

bucket → int
no setter
endX → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
rowNumber ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startX → int
no setter
value → int
no setter
width → int
no setter

Methods

hasValidRowNumber() → bool
isValidRowNumber(int rowNumber) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setRowNumberAsRowIndicatorColumn() → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited