DetectionResult class

@author Guenther Grau

Constructors

DetectionResult(BarcodeMetadata _barcodeMetadata, BoundingBox? boundingBox)

Properties

barcodeColumnCount → int
no setter
barcodeECLevel → int
no setter
barcodeRowCount → int
no setter
boundingBox ↔ BoundingBox?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDetectionResultColumn(int barcodeColumn) → DetectionResultColumn?
getDetectionResultColumns() → List<DetectionResultColumn?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDetectionResultColumn(int barcodeColumn, DetectionResultColumn? detectionResultColumn) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited