DetectionResultColumn class

@author Guenther Grau

Implementers

Constructors

DetectionResultColumn(BoundingBox boundingBox)

Properties

boundingBox → BoundingBox
no setter
codewords → List<Codeword?>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCodeword(int imageRow) → Codeword?
getCodewordNearby(int imageRow) → Codeword?
imageRowToCodewordIndex(int imageRow) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCodeword(int imageRow, Codeword codeword) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited