DetectionResultRowIndicatorColumn class

@author Guenther Grau

Inheritance

Constructors

DetectionResultRowIndicatorColumn(BoundingBox boundingBox, bool isLeft)

Properties

boundingBox → BoundingBox
no setterinherited
codewords → List<Codeword?>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isLeft → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

adjustCompleteIndicatorColumnRowNumbers(BarcodeMetadata barcodeMetadata) → void
getBarcodeMetadata() → BarcodeMetadata?
getCodeword(int imageRow) → Codeword?
inherited
getCodewordNearby(int imageRow) → Codeword?
inherited
getRowHeights() → List<int>?
imageRowToCodewordIndex(int imageRow) → int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCodeword(int imageRow, Codeword codeword) → void
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited