Detector class

Encapsulates logic that can detect a PDF417 Code in an image, even if the PDF417 Code is rotated or skewed, or partially obscured.

@author SITA Lab (kevin.osullivan@sita.aero) @author dswitkin@google.com (Daniel Switkin) @author Guenther Grau

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

detect(BinaryBitmap image, DecodeHint? hints, bool multiple) → PDF417DetectorResult
Detects a PDF417 Code in an image. Checks 0, 90, 180, and 270 degree rotations.