ModulusGF class

A field based on powers of a generator integer, modulo some modulus.

See GenericGF

@author Sean Owen

Properties

hashCode → int
The hash code for this object.
no setterinherited
one → ModulusPoly
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter
zero → ModulusPoly
no setter

Methods

add(int a, int b) → int
buildMonomial(int degree, int coefficient) → ModulusPoly
exp(int a) → int
inverse(int a) → int
log(int a) → int
multiply(int a, int b) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subtract(int a, int b) → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

pdf417Gf → ModulusGF
final