ModulusPoly class

@author Sean Owen

Constructors

ModulusPoly(ModulusGF _field, List<int> coefficients)

Properties

coefficients → List<int>
no setter
degree → int
@return degree of this polynomial
no setter
hashCode → int
The hash code for this object.
no setterinherited
isZero → bool
@return true iff this polynomial is the monomial "0"
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(ModulusPoly other) → ModulusPoly
evaluateAt(int a) → int
@return evaluation of this polynomial at a given point
getCoefficient(int degree) → int
@return coefficient of x^degree term in this polynomial
multiply(int scalar) → ModulusPoly
multiplyByMonomial(int degree, int coefficient) → ModulusPoly
multiplyPoly(ModulusPoly other) → ModulusPoly
negative() → ModulusPoly
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subtract(ModulusPoly other) → ModulusPoly
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited