PDF417ResultMetadata class

@author Guenther Grau

Constructors

PDF417ResultMetadata()

Properties

addressee ↔ String?
getter/setter pair
checksum ↔ int
16-bit CRC checksum using CCITT-16
getter/setter pair
fileId ↔ String?
Is the same for each related PDF417 symbol
getter/setter pair
fileName ↔ String?
Filename of the encoded file
getter/setter pair
fileSize ↔ int
fileSize in bytes of the encoded file
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isLastSegment ↔ bool
Whether if it is the last segment
getter/setter pair
optionalData ↔ List<int>?
optionalData old optional data format as int array
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentCount ↔ int
count of segments, -1 if not set
getter/setter pair
segmentIndex ↔ int
The File segment index represents the segment of the whole file distributed over different symbols.
getter/setter pair
sender ↔ String?
getter/setter pair
timestamp ↔ int
unix epock timestamp, elapsed seconds since 1970-01-01
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited