Detector class

Encapsulates logic that can detect a QR Code in an image, even if the QR Code is rotated or skewed, or partially obscured.

@author Sean Owen

Implementers

Constructors

Detector(BitMatrix _image)

Properties

hashCode → int
The hash code for this object.
no setterinherited
image → BitMatrix
no setter
resultPointCallback → ResultPointCallback?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculateModuleSize(ResultPoint topLeft, ResultPoint topRight, ResultPoint bottomLeft) → double
Computes an average estimated module size based on estimated derived from the positions of the three finder patterns.
detect([DecodeHint? hints]) → DetectorResult
Detects a QR Code in an image.
findAlignmentInRegion(double overallEstModuleSize, int estAlignmentX, int estAlignmentY, double allowanceFactor) → AlignmentPattern
Attempts to locate an alignment pattern in a limited region of the image, which is guessed to contain it. This method uses [AlignmentPattern].
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processFinderPatternInfo(FinderPatternInfo info) → DetectorResult
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited