Edge class

Inheritance

Constructors

Edge(Mode mode, int fromPosition, int charsetEncoderIndex, int characterLength, Edge? previous, Version version, MinimalEncoder context)

Properties

cachedTotalSize ↔ int
getter/setter pair
characterLength → int
final
charsetEncoderIndex → int
final
context → MinimalEncoder
finalinherited
fromPosition → int
final
hashCode → int
The hash code for this object.
no setterinherited
mode → Mode
final
previous → Edge?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited