QRCode class

@author satorux@google.com (Satoru Takabayashi) - creator @author dswitkin@google.com (Daniel Switkin) - ported from C++

Constructors

QRCode({Mode? mode, ErrorCorrectionLevel? ecLevel, Version? version, int maskPattern = -1, ByteMatrix? matrix})

Properties

ecLevel ↔ ErrorCorrectionLevel?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maskPattern ↔ int
getter/setter pair
matrix ↔ ByteMatrix?
getter/setter pair
mode ↔ Mode?
the mode. Not relevant if EncodeHintType.QR_COMPACT is selected.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ Version?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isValidMaskPattern(int maskPattern) → bool

Constants

numMaskPatterns → const int