ResultList class

Inheritance

Constructors

ResultList(Version version, Edge? solution, MinimalEncoder context)

Properties

context → MinimalEncoder
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
list ↔ List<ResultNode>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ Version
getter/setter pair

Methods

getBits(BitArray bits) → void
appends the bits
getSize([Version? version]) → int
returns the size in bits
getVersion() → Version
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited