ResultNode class

Inheritance

Constructors

ResultNode(Mode mode, int fromPosition, int charsetEncoderIndex, int characterLength, ResultList context)

Properties

characterLength → int
final
charsetEncoderIndex → int
final
context → ResultList
finalinherited
fromPosition → int
final
hashCode → int
The hash code for this object.
no setterinherited
mode → Mode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBits(BitArray bits) → void
appends the bits
getCharacterCountIndicator() → int
returns the length in characters according to the specification (differs from getCharacterLength() in BYTE mode
getSize(Version version) → int
returns the size in bits
makePrintable(String s) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited