ReaderException class abstract

The general exception class throw when something goes wrong during decoding of a barcode.

This includes, but is not limited to, failing checksums / error correction algorithms, being unable to locate finder timing patterns, and so on. @author Sean Owen

Implemented types
Implementers

Constructors

ReaderException([dynamic message])

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isStackTrace ↔ bool
getter/setter pair

Static Methods

setStackTrace(bool enabled) → void
Not implemented